import { PluginFunction, PluginValidateFn } from '@graphql-codegen/plugin-helpers';
/**
 * @description This plugin generates an introspection file but only with Interfaces and Unions, based on your GraphQLSchema.
 *
 * If you are using `apollo-client` and your schema contains `interface` or `union` declaration, it's recommended to use Apollo's Fragment Matcher and the result generated by the plugin.
 *
 * You can read more about it in [`apollo-client` documentation](https://apollographql.com/docs/react/data/fragments/#fragments-on-unions-and-interfaces).
 *
 * Fragment Matcher plugin accepts a TypeScript / JavaScript or a JSON file as an output _(`.ts, .tsx, .js, .jsx, .json`)_.
 *
 * Both in TypeScript and JavaScript a default export is being used.
 *
 * > The output is based on the output you choose for the output file name.
 */
export interface FragmentMatcherConfig {
    /**
     * @description Compatible only with JSON extension, allow you to choose the export type, either `module.exports` or `export default`. Allowed values are: `commonjs`, `es2015`.
     * @default es2015
     *
     * @exampleMarkdown
     * ```tsx {10} filename="codegen.ts"
     *  import type { CodegenConfig } from '@graphql-codegen/cli';
     *
     *  const config: CodegenConfig = {
     *    schema: 'https://localhost:4000/graphql',
     *    documents: ['src/**\/*.tsx'],
     *    generates: {
     *      'path/to/file.json': {
     *        plugins: ['fragment-matcher'],
     *        config: {
     *          module: 'commonjs',
     *        },
     *      },
     *    },
     *  };
     *  export default config;
     * ```
     */
    module?: 'commonjs' | 'es2015';
    /**
     * @description Compatible only with TS/TSX/JS/JSX extensions, allow you to generate output based on your Apollo-Client version. Valid values are: `2`, `3`.
     * @default 3
     *
     * @exampleMarkdown
     * ```tsx {10} filename="codegen.ts"
     *  import type { CodegenConfig } from '@graphql-codegen/cli';
     *
     *  const config: CodegenConfig = {
     *    schema: 'https://localhost:4000/graphql',
     *    documents: ['src/**\/*.tsx'],
     *    generates: {
     *      'path/to/file.json': {
     *        plugins: ['fragment-matcher'],
     *        config: {
     *          apolloClientVersion: 3,
     *        },
     *      },
     *    },
     *  };
     *  export default config;
     * ```
     */
    apolloClientVersion?: 2 | 3;
    /**
     * @description Create an explicit type based on your schema. This can help IDEs autofill your fragment matcher. This is mostly useful if you do more with your fragment matcher than just pass it to an Apollo-Client.
     * @default false
     *
     * @exampleMarkdown
     * ```tsx {10} filename="codegen.ts"
     *  import type { CodegenConfig } from '@graphql-codegen/cli';
     *
     *  const config: CodegenConfig = {
     *    schema: 'https://localhost:4000/graphql',
     *    documents: ['src/**\/*.tsx'],
     *    generates: {
     *      'path/to/file.json': {
     *        plugins: ['fragment-matcher'],
     *        config: {
     *          useExplicitTyping: true
     *        },
     *      },
     *    },
     *  };
     *  export default config;
     * ```
     */
    useExplicitTyping?: boolean;
    federation?: boolean;
    /**
     * @description When enabled sorts the fragment types lexicographically. This is useful for deterministic output.
     * @default false
     */
    deterministic?: boolean;
}
export declare const plugin: PluginFunction;
export declare const validate: PluginValidateFn<any>;
